#
# spec file for package python-hijri-converter
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname hijri-converter
Name:           python-hijri-converter
Version:        2.2.4
Release:        2.1
Summary:        Python package to convert accurately between Hijri and Gregorian dates
License:        MIT
URL:            https://github.com/dralshehri/hijri-converter
Source:         https://github.com/dralshehri/%{modname}/archive/v%{version}.tar.gz#/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
A Python package to convert accurately between Hijri and Gregorian dates using the Umm al-Qura calendar of Saudi Arabia.

%prep
%setup -q -n hijri-converter-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc CHANGELOG.md README.md
%{python_sitelib}/hijri_converter
%{python_sitelib}/hijri_converter*info

%changelog
* Tue May 27 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Fri Mar  3 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.2.4:
  * Fixed location of type checking marker file. (#10 bt @dimbleby)
  * Added some missing variable annotations to ummalqura module.
  * Fixed an issue when generating documentation.
  * Fixed some typos in docstrings and improved documentation.
  * Other minor fixes and enhancements.
  * Fixed calculation of month 12 of year 1354 AH.
  * Fixed an issue when generating documentation without the package being
    installed. (#7)
  * Refactored internal helper functions.
  * Added today() classmethod to Hijri class to get the Hijri Object of
    today's date.
  * Added separator and padding parameters to dmyformat() method to have more
    control on formatting.
  * Refactored locales for better management and testing.
  * Updated main classes to be conveniently imported into the package
    level e.g. from hijri_converter import Hijri, Gregorian.
  * Removed deprecated method slashformat() from Hijri and Gregorian classes.
  * Other minor fixes and internal enhancements.
  * Changed Hijri rich comparison to return NotImplemented when the second
    operand is not Hijri class.
  * Updated packaging configuration files and local development workflow.
  * Other minor fixes and documentation enhancements.
  * Added dmyformat() to return dates in DD/MM/YYYY format.
  * Deprecated slashformat() method to be replaced by dmyformat() method.
  * Fixed PyPI package not including some required files. (#3)
- Stop using python_sitelib/*
* Mon Mar 15 2021 Matej Cepl <mcepl@suse.com>
- Switch to the proper upstream tarball.
* Mon Feb  8 2021 Adrian Schröter <adrian@suse.de>
- initial package of version 2.1.1
